simulator_format = {
    'ModelParameters': [
        "TimeStepDuration",
        "TimeStepPerCycle",
        "NumberOfCycle",
        "StartingDate",
        "ManageBacklogQuantities",
        "OptimizationObjective",
        "ActivateUncertainties",
        "EmptyObsoleteStocks",
        "UncertaintiesProbabilityDistribution",
        "ActivateVariableMachineOpeningRate",
        "ImmobilizedCashRelativeCost",
        "BatchSize",
        "ExtraProductionPlanIsAvailable",
        "EnforceProductionPlan",
    ],
    'BE_Stock': [
        "Name",
        "CurrentStock",
        "MinimalStock",
        "MaximalStock",
        "Value",
        "PurchasingUnitCost",
        "CO2UnitEmissions",
        "UnitIncome",
        "Demand",
        "StorageUnitCostSchedule",
        "IsInfinite",
        "StockPolicy",
        "SourcingPolicy",
        "DispatchPolicy",
        "OrderPointSchedule",
        "OrderQuantitySchedule",
        "SchedulingStep",
    ],
    'CE_Machine': [
        "Name",
        "StockTypeProportion",
        "Groups",
        "OpeningRates",
        "OpeningTimeSchedule",
        "ProductionCostSchedule",
        "ProductionPolicy",
    ],
    'BE_Operation': [
        "Name",
        "ParentName",
        "OperatingPerformanceSchedule",
        "CycleTimeSchedule",
        "RejectRateSchedule",
        "OperatingPerformanceUncertaintySchedule",
        "ProductionUnitCostSchedule",
        "CO2UnitEmissionsSchedule",
        "ProductionPlanSchedule",
        "InvestmentCost",
        "IsContractor",
        "Priority",
        "SchedulingStep",
        "FollowsStockPolicy",
    ],
    'BE_TransportOperation': [
        "Name",
        "TransportDuration",
        "InitialTransportQuantity",
        "InitialTransportValue",
        "TransportUnitCostSchedule",
        "CustomsUnitCostSchedule",
        "CO2UnitEmissionsSchedule",
        "Priority",
        "SchedulingStep",
        "FollowsStockPolicy",
    ],
    'EE_StockToOperation': [
        "Name",
        "OperationName",
        "StockName",
        "PropStockForOperation",
        "IsProportion",
        "Groups",
        "Cardinality",
    ],
    'Arcs_OperationToStock': [
        "StockName",
        "OperationName",
    ],
    'IndustrialNetworkScheduler': [
        "Name",
        "Type",
        "TaskName",
    ]
}
